# Camera Extension Specification

**This is a work in progress and has not been reviewed everything is likely to
change**

- **Title**: Camera
- **Identifier**:
  [https://linz.github.io/stac/v0.0.7/camera/schema.json]()
- **Field Name Prefix**: camera
- **Scope**: Item
- **Extension Classification**: Work In Progress (Before proposal)

## Item Properties or Asset Fields

| Field Name                  | Type    | Description                                                                                                                      |
| --------------------------- | ------- | -------------------------------------------------------------------------------------------------------------------------------- |
| camera:sequence_number      | integer | Also referred to as vender; the sequential order of photos taken by an individual camera                                         |
| camera:nominal_focal_length | integer | Distance in mm from the camera lens centre to the film in the camera at which the image will have the least possible distortion. |
